==> getfem-matlab-1.5.tar.gz: getfem-matlab-1.5/src/matlabint_convex_structure.h <==
/* -*- c++ -*- (enables emacs c++ mode)                                    */
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_convex_structure.h                                  */
/*     									           */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard, Julien Pommier.                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef __MATLABINT_CONVEX_STRUCTURE_H
#define __MATLABINT_CONVEX_STRUCTURE_H

#include <matlabint_std.h>
#include <getfem_mat_elem.h>


namespace matlabint
{
  id_type ind_convex_structure(bgeot::pconvex_structure);
  bgeot::pconvex_structure addr_convex_structure(id_type);
  bool exists_convex_structure(id_type);  
}  /* end of namespace matlabint.                                          */

#endif /* __MATLABINT_CONVEX_STRUCTURE_H                                  */

==> getfem-matlab-1.6.tar.gz: getfem-matlab-1.6/src/matlabint_convex_structure.h <==
/* -*- c++ -*- (enables emacs c++ mode)                                    */
/* *********************************************************************** */
/*                                                                         */
/* Library : Matlab Interface (matlabint)                                  */
/* File    : matlabint_convex_structure.h                                  */
/*     									           */
/*                                                                         */
/* *********************************************************************** */
/*                                                                         */
/* Copyright (C) 2001  Yves Renard, Julien Pommier.                        */
/*                                                                         */
/* This file is a part of GETFEM++                                         */
/*                                                                         */
/* This program is free software; you can redistribute it and/or modify    */
/* it under the terms of the GNU General Public License as published by    */
/* the Free Software Foundation; version 2 of the License.                 */
/*                                                                         */
/* This program is distributed in the hope that it will be useful,         */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of          */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           */
/* GNU General Public License for more details.                            */
/*                                                                         */
/* You should have received a copy of the GNU General Public License       */
/* along with this program; if not, write to the Free Software Foundation, */
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.         */
/*                                                                         */
/* *********************************************************************** */


#ifndef MATLABINT_CONVEX_STRUCTURE_H__
#define MATLABINT_CONVEX_STRUCTURE_H__

#include <matlabint_std.h>
#include <bgeot_convex_structure.h>
namespace matlabint
{
  id_type ind_convex_structure(bgeot::pconvex_structure);
  bgeot::pconvex_structure addr_convex_structure(id_type);
  bool exists_convex_structure(id_type);  
}  /* end of namespace matlabint.                                          */

#endif /* MATLABINT_CONVEX_STRUCTURE_H__                                  */
